import { Component, OnInit, HostListener } from '@angular/core';
import { Platform } from '@ionic/angular';
import {
  IonHeader,
  IonToolbar,
  IonTitle,
  IonContent,
  IonCard,
  IonCardTitle,
  IonCardContent,
} from '@ionic/angular/standalone';
import { LegendPosition } from '@swimlane/ngx-charts';
import { NgClass } from '@angular/common';
import { GroupedVerticalBarChartComponent } from '../components/grouped-vertical-bar-chart/grouped-vertical-bar-chart.component';
import { PieChartComponent } from '../components/pie-chart/pie-chart.component';
import { VerticalBarChartComponent } from '../components/vertical-bar-chart/vertical-bar-chart.component';
import { LineChartComponent } from '../components/line-chart/line-chart.component';
import { HorizontalBarChartComponent } from '../components/horizontal-bar-chart/horizontal-bar-chart.component';

@Component({
  selector: 'app-indikator',
  templateUrl: './indikator.page.html',
  styleUrls: ['./indikator.page.scss'],
  standalone: true,
  imports: [
    IonHeader,
    IonToolbar,
    IonTitle,
    IonContent,
    IonCard,
    IonCardTitle,
    IonCardContent,
    NgClass,
    VerticalBarChartComponent,
    GroupedVerticalBarChartComponent,
    PieChartComponent,
    LineChartComponent,
    HorizontalBarChartComponent
  ],
})
export class IndikatorPage implements OnInit {
  view: any;
  legendPosition!: LegendPosition;
  below: boolean = false;

  constructor(private platform: Platform) {}

  ngOnInit() {
    // this.changeLegendPostion(false);
    this.handleScreenSizeChange();
  }
  @HostListener('window:resize', ['$event'])
  onResize(event: any) {
    this.handleScreenSizeChange();
  }

  changeLegendPostion(defaultValue = true) {
    this.legendPosition = defaultValue ? LegendPosition.Right : LegendPosition.Below;
    this.below = !defaultValue;
  }

  handleScreenSizeChange() {
    const width = this.platform.width();
    const height = this.platform.height();
    console.log(width, height);
    if (width > height) {
      this.changeLegendPostion();
      this.view = [0.9 * width, 0.9 * height];
    } else {
      this.changeLegendPostion(false);
      this.view = [0.95 * width, 0.35 * height];
    }
  }
}